@@ -15,6 +15,7 @@ from django.db.models.signals import (
 
 # Django Model Signals
 from django_model_signals.dispatcher import ModelSignalsDispatcher
+from django_model_signals.signals import pre_bulk_save, post_bulk_save
 from django_model_signals.transceiver import ModelSignalsTransceiver
 
 
@@ -44,3 +45,8 @@ class DjangoModelSignalsConfig(AppConfig):
                     post_delete.connect(ModelSignalsDispatcher.post_delete)
                 if 'm2m_changed' in model.ModelSignalsMeta.signals:
                     m2m_changed.connect(ModelSignalsDispatcher.m2m_changed)
+                if 'pre_bulk_save' in model.ModelSignalsMeta.signals:
+                    pre_bulk_save.connect(ModelSignalsDispatcher.pre_bulk_save)
+                if 'post_bulk_save' in model.ModelSignalsMeta.signals:
+                    post_bulk_save.connect(
+                        ModelSignalsDispatcher.post_bulk_save)
